@@ -2,6 +2,10 @@ context("ecr")
 
 svc <- paws::ecr()
 
+test_that("describe_registry", {
+  expect_error(svc$describe_registry(), NA)
+})
+
 test_that("describe_repositories", {
   expect_error(svc$describe_repositories(), NA)
 })
